@@ -1,4 +1,4 @@
-/*      $Id: client.h 29542 2009-02-23 10:06:52Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -64,7 +64,8 @@
 #define CFG_CONSTRAINED                 (1<<0)
 #define CFG_REQUEST                     (1<<1)
 #define CFG_NOTIFY                      (1<<2)
-#define CFG_FORCE_REDRAW                (1<<3)
+#define CFG_KEEP_VISIBLE                (1<<3)
+#define CFG_FORCE_REDRAW                (1<<4)
 
 #define INCLUDE_HIDDEN                  (1<<0)
 #define INCLUDE_SHADED                  (1<<1)
@@ -190,8 +191,8 @@
                                          WINDOW_UTILITY | \
                                          WINDOW_SPLASHSCREEN)
 #define WINDOW_REGULAR_FOCUSABLE        (WINDOW_NORMAL | \
-                                         WINDOW_DIALOG | \
-                                         WINDOW_MODAL_DIALOG)
+                                         WINDOW_TYPE_DIALOG | \
+                                         WINDOW_UTILITY)
 #define WINDOW_TYPE_DONT_FOCUS          (WINDOW_SPLASHSCREEN | \
                                          WINDOW_DOCK)
 
@@ -389,7 +390,8 @@ void                     clientWithdrawAll                      (Client *,
 void                     clientClearAllShowDesktop              (ScreenInfo *);
 void                     clientToggleShowDesktop                (ScreenInfo *);
 void                     clientActivate                         (Client *,
-                                                                 guint32);
+                                                                 guint32,
+                                                                 gboolean);
 void                     clientClose                            (Client *);
 void                     clientKill                             (Client *);
 void                     clientTerminate                        (Client *);
