@@ -1,4 +1,4 @@
-/*      $Id: focus.c 29658 2009-03-13 10:36:42Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -214,7 +214,12 @@ clientFocusNew(Client * c)
     {
         Client *c2 = clientGetFocus();
 
-        if ((c2 != NULL) && (c2->win_layer == c->win_layer))
+        /*
+         * Place windows under the currently focused only if focus
+         * stealing prevention had prevented the focus transition,
+         * otherwise, leave the unfocused window on top.
+         */
+        if ((c2 != NULL) && (c2->win_layer == c->win_layer) && prevented)
         {
             clientSortRing(c);
             clientLower (c, c2->frame);
