@@ -1,4 +1,4 @@
-/*      $Id: screen.c 29514 2009-02-19 09:56:25Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -531,6 +531,8 @@ myScreenGetKeyPressed (ScreenInfo *screen_info, XKeyEvent * ev)
 {
     int key, state;
 
+    TRACE ("entering myScreenGetKeyPressed");
+
     state = ev->state & MODIFIER_MASK;
     for (key = 0; key < KEY_COUNT; key++)
     {
@@ -566,10 +568,47 @@ myScreenGetClientFromWindow (ScreenInfo *screen_info, Window w, unsigned short m
     return NULL;
 }
 
+gboolean
+myScreenComputeSize (ScreenInfo *screen_info)
+{
+    gint num_monitors, i;
+    gint width, height;
+    GdkRectangle monitor;
+    gboolean changed;
+
+    g_return_val_if_fail (screen_info != NULL, FALSE);
+    g_return_val_if_fail (GDK_IS_SCREEN (screen_info->gscr), FALSE);
+    TRACE ("entering myScreenComputeSize");
+
+    width = 0;
+    height = 0;
+    num_monitors = gdk_screen_get_n_monitors (screen_info->gscr);
+
+    if (num_monitors == 0)
+    {
+        return FALSE;
+    }
+
+    for (i = 0; i < num_monitors; i++)
+    {
+        gdk_screen_get_monitor_geometry (screen_info->gscr, i, &monitor);
+        width = MAX (monitor.x + monitor.width, width);
+        height = MAX (monitor.y + monitor.height, height);
+    }
+
+    changed = ((screen_info->width != width) | (screen_info->height != height));
+    screen_info->width = width;
+    screen_info->height = height;
+    TRACE ("myScreenComputeSize(): width=%i, height=%i", width, height);
+
+    return changed;
+}
+
 void
 myScreenInvalidateMonitorCache (ScreenInfo *screen_info)
 {
     g_return_if_fail (screen_info != NULL);
+    TRACE ("entering myScreenInvalidateMonitorCache");
 
     screen_info->cache_monitor.x = G_MAXINT;
     screen_info->cache_monitor.y = G_MAXINT;
@@ -591,6 +630,7 @@ myScreenFindMonitorAtPoint (ScreenInfo *screen_info, gint x, gint y, GdkRectangl
     g_return_if_fail (screen_info != NULL);
     g_return_if_fail (rect != NULL);
     g_return_if_fail (GDK_IS_SCREEN (screen_info->gscr));
+    TRACE ("entering myScreenFindMonitorAtPoint");
 
     /* Cache system */
     if ((x >= screen_info->cache_monitor.x) && (x < screen_info->cache_monitor.x + screen_info->cache_monitor.width) &&
@@ -643,6 +683,9 @@ myScreenUpdateFontHeight (ScreenInfo *screen_info)
     PangoLanguage *language;
     GtkWidget *widget;
 
+    g_return_val_if_fail (screen_info != NULL, FALSE);
+    TRACE ("entering myScreenUpdateFontHeight");
+
     widget = myScreenGetGtkWidget (screen_info);
     context = getUIPangoContext (widget);
     desc = getUIPangoFontDesc (widget);
@@ -660,5 +703,4 @@ myScreenUpdateFontHeight (ScreenInfo *screen_info)
     }
 
     return FALSE;
-
 }
